﻿using System.IO;
using System.Reflection;
using System.Web.Hosting;

namespace FortuneCookie.EPiServer.SearchAndReplace
{
    /// <summary>
    /// Resource virtual file class
    /// </summary>
    internal class ResourceVirtualFile : VirtualFile
    {

        #region Members

        private readonly string _resourceName;
        private readonly bool _physicalResource;

        #endregion Members

        #region Constructor

        /// <summary>
        /// Default constructor
        /// </summary>
        /// <param name="virtualPath"></param>
        /// <param name="resourceName"></param>
        /// <param name="physicalResource"></param>
        public ResourceVirtualFile(string virtualPath, string resourceName, bool physicalResource) : base(virtualPath)
        {
            _resourceName = resourceName;
            _physicalResource = physicalResource;
        }

        #endregion Constructor

        #region Methods

        /// <summary>
        /// Opens the resource stream
        /// </summary>
        /// <returns></returns>
        public override Stream Open()
        {
            return !_physicalResource
                       ? Assembly.GetExecutingAssembly().GetManifestResourceStream(_resourceName)
                       : File.OpenRead(_resourceName);
        }

        #endregion Methods
    }
}
